"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const run_tasks_in_serial_1 = require("@nx/workspace/src/utilities/run-tasks-in-serial");
const path = require("path");
function normalizeOptions(host, options) {
    const name = (0, devkit_1.names)(options.name).fileName;
    const projectDirectory = options.directory
        ? `${(0, devkit_1.names)(options.directory).fileName}/${name}`
        : name;
    const projectName = projectDirectory.replace(new RegExp('/', 'g'), '-');
    const projectRoot = (0, devkit_1.joinPathFragments)((0, devkit_1.getWorkspaceLayout)(host).appsDir, projectDirectory);
    const parsedTags = options.tags
        ? options.tags.split(',').map((s) => s.trim())
        : [];
    return Object.assign(Object.assign({}, options), { projectName,
        projectRoot,
        projectDirectory,
        parsedTags });
}
function addFiles(host, options) {
    (0, devkit_1.generateFiles)(host, path.join(__dirname, 'files-http'), options.projectRoot, Object.assign(Object.assign(Object.assign({}, options), (0, devkit_1.names)(options.name)), { offsetFromRoot: (0, devkit_1.offsetFromRoot)(options.projectRoot), template: '' }));
}
function default_1(host, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = normalizeOptions(host, options);
        (0, devkit_1.addProjectConfiguration)(host, normalizedOptions.projectName, {
            root: normalizedOptions.projectRoot,
            projectType: 'application',
            sourceRoot: `${normalizedOptions.projectRoot}/src`,
            targets: {
                lint: {
                    executor: '@nrwl/linter:eslint',
                    options: {}
                },
                test: {
                    executor: '@nx/jest:jest',
                    options: {
                        jestConfig: `${normalizedOptions.projectRoot}/jest.config.ts`,
                        passWithNoTests: true
                    }
                },
                build: {
                    executor: '@nx-extend/gcp-functions:build',
                    options: {
                        generateLockFile: true,
                        outputPath: `dist/${normalizedOptions.projectRoot}`,
                        main: `${normalizedOptions.projectRoot}/src/main.ts`,
                        tsConfig: `${normalizedOptions.projectRoot}/tsconfig.app.json`,
                        assets: []
                    },
                    configurations: {
                        production: {
                            optimization: true,
                            extractLicenses: false,
                            inspect: false
                        }
                    }
                },
                deploy: {
                    executor: '@nx-extend/gcp-functions:deploy',
                    options: {
                        functionName: normalizedOptions.projectName,
                        envVarsFile: `${normalizedOptions.projectRoot}/src/environments/production.yaml`
                    }
                }
            },
            tags: normalizedOptions.parsedTags
        });
        addFiles(host, normalizedOptions);
        yield (0, devkit_1.formatFiles)(host);
        return (0, run_tasks_in_serial_1.runTasksInSerial)((0, devkit_1.addDependenciesToPackageJson)(host, {}, {
            '@google-cloud/functions-framework': 'latest'
        }));
    });
}
exports.default = default_1;
//# sourceMappingURL=init.impl.js.map