"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generatePackageJson = void 0;
const devkit_1 = require("@nx/devkit");
const js_1 = require("@nx/js");
const project_graph_1 = require("@nx/workspace/src/core/project-graph");
const fileutils_1 = require("@nx/workspace/src/utils/fileutils");
const fs = require("fs");
const lock_file_1 = require("nx/src/plugins/js/lock-file/lock-file");
const path_1 = require("path");
const generatePackageJson = (context, options, outFile, generateLockFile) => {
    const { root } = context.workspace.projects[context.projectName];
    const packageJson = (0, js_1.createPackageJson)(context.projectName, (0, project_graph_1.readCachedProjectGraph)(), {
        root: context.root,
        isProduction: true
    });
    if (!packageJson.main) {
        packageJson.main = options.outputFileName || 'main.js';
    }
    delete packageJson.devDependencies;
    const dependencies = {};
    const buildFile = fs.readFileSync(outFile, 'utf8');
    const re2 = /"(.*)"/gm;
    const externalDependencies = buildFile.match(/require\("(.*?)"\)/gm);
    // Get the package version from the root
    if (externalDependencies) {
        const workspacePackages = (0, devkit_1.readJsonFile)((0, path_1.join)(context.root, 'package.json'));
        const dependenciesName = externalDependencies.map((x) => x.match(re2)[0].replace(/"/gm, ''));
        dependenciesName.forEach((dep) => {
            let depName = dep;
            let packageIsDefined = depName in workspacePackages.dependencies;
            if (!packageIsDefined) {
                if (depName.includes('/')) {
                    depName = depName.split('/').shift();
                    packageIsDefined = depName in workspacePackages.dependencies;
                }
            }
            if (packageIsDefined) {
                dependencies[depName] = workspacePackages.dependencies[depName];
            }
            else {
                console.warn(`Could not add "${dep}", is it added to the package.json?`);
            }
        });
    }
    const projectPackageJson = (0, path_1.join)(root, 'package.json');
    const originalPackageJson = (0, fileutils_1.fileExists)(projectPackageJson)
        ? (0, devkit_1.readJsonFile)(projectPackageJson)
        : { dependencies: {} };
    packageJson.dependencies = Object.assign(Object.assign({}, originalPackageJson.dependencies), dependencies);
    if (!packageJson.devDependencies) {
        packageJson.devDependencies = {};
    }
    if (originalPackageJson.main) {
        packageJson.main = originalPackageJson.main;
    }
    (0, devkit_1.writeJsonFile)(`${options.outputPath}/package.json`, packageJson);
    if (generateLockFile) {
        fs.writeFileSync(`${options.outputPath}/${(0, lock_file_1.getLockFileName)()}`, (0, js_1.createLockFile)(packageJson), {
            encoding: 'utf-8'
        });
    }
};
exports.generatePackageJson = generatePackageJson;
//# sourceMappingURL=generate-package-json.js.map